@@ -1,5 +1,6 @@
 import json
 import os
+from enum import IntEnum
 from typing import List
 
 import requests
@@ -9,6 +10,11 @@ from i2a_chat_api_client.exceptions import I2AChatApiClientUnauthorizedException
     I2AChatApiClientNotFoundError
 
 
+class ChatRoomType(IntEnum):
+    REGULAR = 1
+    MASS = 2
+
+
 class I2aChatApiServer:
     STAGE = 'https://chat-server-stg.i2asolutions.com'
     PRODUCTION = NotImplemented
@@ -100,16 +106,18 @@ class I2AChatApiClient:
         else:
             raise Exception(f'Close session failed. {self._status_code_message(response)}')
 
-    def create_chat_room(self, application_users_identifiers: List[str]):
+    def create_chat_room(self, application_users_identifiers: List[str], chat_room_type: ChatRoomType):
         """
         Creates new chat room
+        :param chat_room_type: int -> ChatRoomType enum value
         :param application_users_identifiers: [str,]
         :return: chat_room_identifier: str
         """
 
         url = self._get_full_url('chat-room/')
         data = {
-            'application_users_identifiers': application_users_identifiers
+            'application_users_identifiers': application_users_identifiers,
+            'type': chat_room_type.value
         }
         response = requests.post(url, data, headers=self._required_headers())
         if response.status_code == 201:
@@ -208,11 +216,20 @@ class I2AChatApiClient:
         else:
             raise Exception(f'Send system message failed. {self._status_code_message(response)}')
 
-    def report_chat_message(self, application_user_identifier, message_timestamp_identifier, message=None):
+    def report_chat_message(
+        self,
+        application_user_identifier,
+        chat_room_identifier,
+        message_timestamp_identifier,
+        report_type=None,
+        message=None
+    ):
         """
         Queuing system message to be saved and send on websocket in provided chat room
         :param application_user_identifier: str
+        :param chat_room_identifier: str
         :param message_timestamp_identifier: str
+        :param report_type: int
         :param message: str
         :return: response - identifier (str)
        """
@@ -220,6 +237,8 @@ class I2AChatApiClient:
         data = {
             'application_user_identifier': application_user_identifier,
             'message_timestamp_identifier': message_timestamp_identifier,
+            'chat_room_identifier': chat_room_identifier,
+            'report_type': report_type,
             'message': message
         }
         response = requests.post(url, data, headers=self._required_headers())
